@@ -937,8 +937,8 @@ make_xy = function(frml, df){
       x <- matrix(0, nrow = nrow(df), ncol = 0)
     }
   }
-  if(any(is.na(x))){ stop("Not allowed to have NAs for predictors") }
-  
+  if(nrow(x) < nrow(df)){ stop("Not allowed to have NAs for predictors") }
+
   # icenReg does not use intercepts
   if('(Intercept)' %in% colnames(x)){	
     ind = which(colnames(x) == '(Intercept)')
